{%- if filetype_loop == 0 %}
```mermaid
flowchart LR;
{%- for interface in to_parse_arp %}
{%-     if to_parse_arp[interface].ipv4 is defined %}
{%-         for neighbor in to_parse_arp[interface].ipv4.neighbors %}
{{ hostname }} <--> {{ interface }} <--> {{ neighbor }} <--> {{ to_parse_arp[interface].ipv4.neighbors[neighbor].link_layer_address }}
{%-        endfor %}
{%-     endif %}
{%- endfor %}
```
{%- else %}{%- if filetype_loop == 1 %}
{%- for interface in to_parse_arp %}
{%-     if to_parse_arp[interface].ipv4 is defined %}
{%-         for neighbor in to_parse_arp[interface].ipv4.neighbors %}
```mermaid
classDiagram
class {{ interface | replace("/","_")}}{
IP: {{ neighbor }}
MAC: {{ to_parse_arp[interface].ipv4.neighbors[neighbor].link_layer_address }}
Origin: {{ to_parse_arp[interface].ipv4.neighbors[neighbor].origin }}
}
```
{%-        endfor %}
{%-     endif %}
{%- endfor %}
{%- else %}{%- if filetype_loop == 2 %}
{%- for interface in to_parse_arp %}
{%-     if to_parse_arp[interface].ipv4 is defined %}
{%-         for neighbor in to_parse_arp[interface].ipv4.neighbors %}
```mermaid
stateDiagram
{{ hostname }} --> {{ interface }}
{{ interface }} --> {{ neighbor }}
{{ neighbor }} --> {{ to_parse_arp[interface].ipv4.neighbors[neighbor].link_layer_address }}
state {{ to_parse_arp[interface].ipv4.neighbors[neighbor].link_layer_address }}{
Origin --

}
```
{%-        endfor %}
{%-     endif %}
{%- endfor %}
{%- else %}{%- if filetype_loop == 3 %}
```mermaid
erDiagram

}
```
{%- endif %}{%- endif %}{%- endif %}{%- endif %}